Module subdivide
rust_3d
0.34.0
Module subdivide
Module Items
Functions
In crate rust_
3d
rust_3d
Module
subdivide
Subdivision algorithms to e.g. refine meshes
Functions

linear
Subdivides a mesh linearly by creating four faces for each input face This will not smoothen the input mesh, since new vertices are placed only on existing edges