HasBoundingBox2DMaybe

Trait HasBoundingBox2DMaybe 

pub trait HasBoundingBox2DMaybe {
    // Required method
    fn bounding_box_maybe(&self) -> Result<BoundingBox2D>;
}
HasBoundingBox2DMaybe is a trait for types which might have a bounding box

Required Methods

fn bounding_box_maybe(&self) -> Result<BoundingBox2D>

Should return the bounding box if it can be calculated

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors