HasBoundingBox3DMaybe

Trait HasBoundingBox3DMaybe 

pub trait HasBoundingBox3DMaybe {
    // Required method
    fn bounding_box_maybe(&self) -> Result<BoundingBox3D>;
}
HasBoundingBox3DMaybe is a trait for types which might have a bounding box

Required Methods

fn bounding_box_maybe(&self) -> Result<BoundingBox3D>

Should return the bounding box if it can be calculated

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors