pub trait IsBox3DSearchable<T> {
// Required method
fn in_box(&self, box_3d: &Box3D, result: &mut Vec<T>);
}Expand description
IsBox3DSearchable trait used for search structures which can be queried for elements within a 3D box You should only implement this, if your solution is rather efficient
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".