IsFilterRandomAccessible

Trait IsFilterRandomAccessible 

pub trait IsFilterRandomAccessible<RA, T>
where RA: IsRandomAccessible<T>,
{ // Required method fn filter(&self, ra: &RA, view: &mut View); }
IsFilterRandomAccessible is a trait used for filters for random accessible collections

Required Methods

fn filter(&self, ra: &RA, view: &mut View)

Should filter the passed elements by setting the flags within the view

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors