IsPlane3D

Trait IsPlane3D 

pub trait IsPlane3D<P, N>: Sized
where P: Is3D, N: IsNormalized3D,
{ // Required methods fn new(origin: P, u: N, v: N) -> Self; fn origin(&self) -> P; fn u(&self) -> N; fn v(&self) -> N; }
IsPlane3D is a trait used for planes within 3D space

Required Methods

fn new(origin: P, u: N, v: N) -> Self

Should return a new plane with the given origin, u and v vectors

fn origin(&self) -> P

Should return the origin of the plane

fn u(&self) -> N

Should return the u vector of the plane

fn v(&self) -> N

Should return the v vector of the plane

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<P, N> IsPlane3D<P, N> for Plane3D<P, N>