pub trait IsSphereSearchable<T> {
// Required method
fn in_sphere(&self, sphere: &Sphere, result: &mut Vec<T>);
}Expand description
IsSphereSearchable trait used for search structures which can be queried for elements within a sphere You should only implement this, if your solution is rather efficient
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".