Trait rust_3d::traits::IsBox3DSearchable [] [src]

pub trait IsBox3DSearchable<PSearch, PFind> where
    PSearch: Is3D,
    PFind: Is3D
{ fn in_box(
        &self,
        search: &PSearch,
        x_size: f64,
        y_size: f64,
        z_size: f64
    ) -> Vec<PFind>; }

IsBox3DSearchable trait used for search structures which can be queried for elements within a 3D box You should only implement this, if your solution is rather efficient

Required Methods

Should return all positions within a box around search

Implementors