pub trait HasBoundingBox2D: HasBoundingBox2DMaybe {
// Required method
fn bounding_box(&self) -> BoundingBox2D;
}Expand description
HasBoundingBox2D is a trait for types which have a bounding box
Required Methods
Sourcefn bounding_box(&self) -> BoundingBox2D
fn bounding_box(&self) -> BoundingBox2D
Should return the bounding box if it can be calculated
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".