pub trait IsBuildableND: Sized + IsND {
// Required methods
fn new_nd(coords: &[f64]) -> Result<Self>;
fn from_nd<P>(&mut self, other: P) -> Result<()>
where P: IsBuildableND;
// Provided methods
fn zero_nd() -> Result<Self> { ... }
fn center_nd<P>(&self, other: &P, buffer: &mut Vec<f64>) -> Result<Self>
where P: IsND { ... }
}Expand description
IsBuildableND is a trait used for types which are positioned in n-dimensional space and can be constructed
Required Methods
Sourcefn new_nd(coords: &[f64]) -> Result<Self>
fn new_nd(coords: &[f64]) -> Result<Self>
Should build an object from the correct number of coordinates
Sourcefn from_nd<P>(&mut self, other: P) -> Result<()>where
P: IsBuildableND,
fn from_nd<P>(&mut self, other: P) -> Result<()>where
P: IsBuildableND,
Should use the coordinates of another as its own
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".