pub trait IsKNearestSearchable<Search, Find> {
// Required methods
fn nearest(&self, search: &Search) -> Result<Find>;
fn knearest(&self, search: &Search, n: usize, result: &mut Vec<Find>);
}Expand description
IsKNearestSearchable trait used for search structures which can be queried for nearest neighbours. You should only implement this, if your solution is rather efficient
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".